% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Bacon.R
\name{Bacon.Age.d}
\alias{Bacon.Age.d}
\title{Output all ages for a single depth.}
\usage{
Bacon.Age.d(d, set = get("info"), its = set$output, BCAD = set$BCAD)
}
\arguments{
\item{d}{The depth of which Bacon age estimates are to be returned. Has to be a single depth.}

\item{set}{Detailed information of the current run, stored within this session's memory as variable info.}

\item{its}{The set of MCMC iterations to be used. Defaults to the entire MCMC output, \code{its=set$output}.}

\item{BCAD}{The calendar scale of graphs and age output-files is in \code{cal BP} by default, but can be changed to BC/AD using \code{BCAD=TRUE}.}
}
\value{
Outputs all MCMC-derived ages for a given depth.
}
\description{
Output all MCMC-derived age estimates for a given depth.
}
\details{
Obtaining an age-depth model is often only a step towards a goal, e.g., plotting a core's 
fossil series ('proxies') against calendar time. Bacon.Age.d can be used to list all MCMC-derived age estimates for a given (single) depth, for example to calculate mean ages for a depth.
}
\examples{
Bacon(run=FALSE)
agedepth(yr.res=50)
ages.d20 = Bacon.Age.d(20)
mean(ages.d20)
}
\references{
Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive 
gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474. 
 \url{https://projecteuclid.org/download/pdf_1/euclid.ba/1339616472}
}
\seealso{
\url{http://www.chrono.qub.ac.uk/blaauw/manualBacon_2.3.pdf}
}
\author{
Maarten Blaauw, J. Andres Christen
}
